@@ -1,7 +1,7 @@
 """
 Type annotations for opensearch service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/literals.html)
 
 Usage::
 
@@ -44,10 +44,7 @@ __all__ = (
     "UpgradeStatusType",
     "UpgradeStepType",
     "VolumeTypeType",
-    "OpenSearchServiceServiceName",
     "ServiceName",
-    "ResourceServiceName",
-    "RegionName",
 )
 
 
@@ -216,7 +213,6 @@ TimeUnitType = Literal["HOURS"]
 UpgradeStatusType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED", "SUCCEEDED_WITH_ISSUES"]
 UpgradeStepType = Literal["PRE_UPGRADE_CHECK", "SNAPSHOT", "UPGRADE"]
 VolumeTypeType = Literal["gp2", "io1", "standard"]
-OpenSearchServiceServiceName = Literal["opensearch"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -505,38 +501,3 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
-RegionName = Literal[
-    "af-south-1",
-    "ap-east-1",
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-northeast-3",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-north-1",
-    "eu-south-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-west-3",
-    "me-south-1",
-    "sa-east-1",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
