@@ -1,7 +1,7 @@
 """
 Type annotations for opensearch service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/type_defs.html)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence, Union
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AutoTuneDesiredStateType,
     AutoTuneStateType,
